pub struct FrameBuffer<'a> { /* private fields */ }Expand description
A structure representing a frame buffer.
Implementations
Sourceimpl<'a> FrameBuffer<'a>
impl<'a> FrameBuffer<'a>
Sourcepub fn new(buffer: &'a mut [u8], width: u32, height: u32) -> Self
pub fn new(buffer: &'a mut [u8], width: u32, height: u32) -> Self
Creates a new frame buffer.
Arguments
buffer- A mutable slice representing the pixel data.width- The width of the frame buffer.height- The height of the frame buffer.
Sourcepub fn get_buffer(&self) -> &[u8]
pub fn get_buffer(&self) -> &[u8]
Sourcepub fn clear(&mut self, color: Rgb565)
pub fn clear(&mut self, color: Rgb565)
Clears the frame buffer with the specified color.
Arguments
color- The color to clear the buffer with.
Sourcepub fn copy_region(
&mut self,
src_buffer: &[u8],
src_x: u16,
src_y: u16,
src_width: u32,
src_height: u32,
dest_x: u16,
dest_y: u16,
)
pub fn copy_region( &mut self, src_buffer: &[u8], src_x: u16, src_y: u16, src_width: u32, src_height: u32, dest_x: u16, dest_y: u16, )
Copies a region from another buffer into this buffer.
Arguments
src_buffer- The source buffer.src_x- The x-coordinate of the top-left corner of the source region.src_y- The y-coordinate of the top-left corner of the source region.src_width- The width of the source region.src_height- The height of the source region.dest_x- The x-coordinate of the top-left corner of the destination region.dest_y- The y-coordinate of the top-left corner of the destination region.
Sourcepub fn copy_regions(&mut self, src_buffer: &[u8], regions: &[Option<Region>])
pub fn copy_regions(&mut self, src_buffer: &[u8], regions: &[Option<Region>])
Restores regions from a source buffer into the frame buffer.
Arguments
src_buffer- The source buffer.regions- An array of regions to restore.